@@ -12,7 +12,7 @@ print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
 print(colored("Welcome to F61D. Use Help() for help.",'green'))
 
 help_cont = {}
-help_cont[0] = 'Help     : See this help page'
+help_cont[0] = 'Help     : See this help page.\n\t\t  '+colored('Help(0)','cyan')+colored(' for all functions.','green')
 help_cont[1] = 'fuckStar : One Button to fuck Satellite'
 help_cont[9] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
